@@ -1,21 +1,8 @@
-// File_Gxf - Info for GXF (SMPTE 360M) files
-// Copyright (C) 2010-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -124,6 +111,7 @@ const char* Gxf_MediaTypes(int8u Type)
         case 22 : return "MPEG-1 Video"; //525 lines
         case 23 : return "MPEG-1 Video"; //625 lines
         case 24 : return "SMPTE 12M"; //HD
+        case 25 : return "DV"; //DVCPRO HD
         default : return "Unknown";
     }
 }
@@ -153,6 +141,7 @@ stream_t Gxf_MediaTypes_StreamKind(int8u Type)
         case 22 : return Stream_Video;
         case 23 : return Stream_Video;
         case 24 : return Stream_Max;
+        case 25 : return Stream_Video;
         default : return Stream_Max;
     }
 }
@@ -177,6 +166,7 @@ const char* Gxf_MediaTypes_Format(int8u Type)
         case 20 : return "MPEG Video"; //HD, Main Profile at High Level
         case 22 : return "MPEG Video"; //525 lines
         case 23 : return "MPEG Video"; //625 lines
+        case 25 : return "DV"; //DVCPRO HD
         default : return "";
     }
 }
@@ -271,6 +261,7 @@ File_Gxf::File_Gxf()
         Ancillary=NULL;
     #endif //defined(MEDIAINFO_ANCILLARY_YES)
     SizeToAnalyze=16*1024*1024;
+    IsParsingMiddle_MaxOffset=(int64u)-1;
     Audio_Count=0;
     Element_Code=0x00; //Element_Code is used as a test for pre-existing parsing, it must be initialized
 
@@ -376,13 +367,13 @@ void File_Gxf::Streams_Finish()
         if (TimeCode_FirstFrame_ms!=(int64u)-1)
         {
             Stream_Prepare(Stream_Other);
+            Fill(Stream_Other, StreamPos_Last, Other_CodecID, Streams[TimeCode->first].MediaType);
             Fill(Stream_Other, StreamPos_Last, Other_ID, TimeCode->first);
             Fill(Stream_Other, StreamPos_Last, Other_Type, "Time code");
             Fill(Stream_Other, StreamPos_Last, Other_Format, "SMPTE TC");
-            //Fill(Stream_Other, StreamPos_Last, Other_MuxingMode, "Time code track");
             Fill(Stream_Other, StreamPos_Last, Other_TimeCode_FirstFrame, TimeCode_FirstFrame.c_str());
             if (TimeCode_FirstFrame_Striped)
-                Fill(Stream_Other, StreamPos_Last, Other_TimeCode_Settings, "Striped");
+                Fill(Stream_Other, StreamPos_Last, Other_TimeCode_Striped, "Yes");
             if (TimeCode->first<Streams.size())
                 Fill(Stream_Other, StreamPos_Last, Other_Title, Streams[TimeCode->first].MediaName);
         }
@@ -446,10 +437,18 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                     }
 
                 Merge(*Temp.Parsers[0], Stream_Video, 0, StreamPos_Last);
+                Fill(Stream_Video, StreamPos_Last, Video_CodecID, Temp.MediaType);
 
                 Fill(Stream_Video, StreamPos_Last, Video_ID, StreamID, 10, true);
                 Fill(Stream_Video, StreamPos_Last, "Title", Temp.MediaName);
 
+                Ztring LawRating=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_LawRating);
+                if (!LawRating.empty())
+                    Fill(Stream_General, 0, General_LawRating, LawRating, true);
+                Ztring Title=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_Title);
+                if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+                    Fill(Stream_General, 0, General_Title, Title);
+
                 //Special cases
                 if (Temp.Parsers[0]->Count_Get(Stream_Text))
                 {
@@ -477,6 +476,7 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
             for (size_t Pos=0; Pos<Temp.Parsers[0]->Count_Get(Stream_Audio); Pos++)
             {
                 Stream_Prepare(Stream_Audio);
+                Fill(Stream_Audio, StreamPos_Last, Audio_CodecID, Temp.MediaType);
 
                 if (TimeCodes.empty())
                 {
@@ -524,7 +524,9 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 Fill(StreamKind_Last, StreamPos_Last, "Title", Temp.MediaName); //Second half of the channel grouping or standalone
 
                 for (std::map<std::string, Ztring>::iterator Info=Temp.Infos.begin(); Info!=Temp.Infos.end(); ++Info)
-                    if (Retrieve(Stream_Audio, StreamPos_Last, Info->first.c_str()).empty())
+                    if (Info->first=="BitRate" && Temp.Parsers[0]->Count_Get(Stream_Audio)>1)
+                        Fill(Stream_Audio, StreamPos_Last, Audio_BitRate_Encoded, Pos?Ztring(__T("0")):Info->second); // In case of more than 1 audio sub-stream Encoded bit rate is the bit rate of all streams + overhead
+                    else if (Retrieve(Stream_Audio, StreamPos_Last, Info->first.c_str()).empty())
                         Fill(Stream_Audio, StreamPos_Last, Info->first.c_str(), Info->second);
             }
 
@@ -546,6 +548,13 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                     Fill(Stream_Text, StreamPos_Last, "Title", Temp.MediaName);
                 }
 
+                Ztring LawRating=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_LawRating);
+                if (!LawRating.empty())
+                    Fill(Stream_General, 0, General_LawRating, LawRating, true);
+                Ztring Title=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_Title);
+                if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+                    Fill(Stream_General, 0, General_Title, Title);
+
                 StreamKind_Last=Stream_Max;
                 StreamPos_Last=(size_t)-1;
             }
@@ -557,6 +566,7 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 for (size_t Parser_Other_Pos=0; Parser_Other_Pos<Parser_Other_Count; Parser_Other_Pos++)
                 {
                     Stream_Prepare(Stream_Other);
+                    Fill(Stream_Other, StreamPos_Last, Other_CodecID, Temp.MediaType);
                     Merge(*Temp.Parsers[0], Stream_Other, Parser_Other_Pos, StreamPos_Last);
                     Ztring ID=Retrieve(Stream_Other, StreamPos_Last, Other_ID);
                     Fill(Stream_Other, StreamPos_Last, Other_ID, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
@@ -763,6 +773,18 @@ size_t File_Gxf::Read_Buffer_Seek (size_t Method, int64u Value, int64u)
 }
 #endif //MEDIAINFO_SEEK
 
+//---------------------------------------------------------------------------
+void File_Gxf::Read_Buffer_AfterParsing()
+{
+    if (File_GoTo==(int64u)-1 && File_Offset+Buffer_Offset>=IsParsingMiddle_MaxOffset)
+    {
+        Fill();
+        Open_Buffer_Unsynch();
+        Finish();
+        return;
+    }
+}
+
 //***************************************************************************
 // Buffer - Per element
 //***************************************************************************
@@ -772,13 +794,13 @@ bool File_Gxf::Header_Begin()
 {
     #if MEDIAINFO_DEMUX
         //Handling of multiple frames in one block
-        if (Element_Code==0xBF && Config->Demux_Unpacketize_Get()) //media block
-            for (size_t Pos=0; Pos<Streams[TrackNumber].Parsers.size(); Pos++)
-            {
-                Open_Buffer_Continue(Streams[TrackNumber].Parsers[Pos], Buffer+Buffer_Offset, 0);
-                if (Config->Demux_EventWasSent)
-                    return false;
-            }
+        if (Element_Code==0xBF && Config->Demux_Unpacketize_Get() && Streams[TrackNumber].Demux_EventWasSent) //media block
+        {
+            Open_Buffer_Continue(Streams[TrackNumber].Parsers[0], Buffer+Buffer_Offset, 0);
+            if (Config->Demux_EventWasSent)
+                return false;
+            Streams[TrackNumber].Demux_EventWasSent=false;
+        }
     #endif //MEDIAINFO_DEMUX
 
     return true;
@@ -1044,7 +1066,9 @@ void File_Gxf::map()
                         case 13 :
                         case 14 :
                         case 15 :
-                        case 16 :   //DV
+                        case 16 :
+                        case 25 :   // was found for DVCPro HD in some files (not in SMPTE ST 360-2009, maybe it is present in a later version)
+                                    //DV
                                     {
                                         File__Analyze* Parser=new File_DvDif();
                                         Open_Buffer_Init(Parser);
@@ -1442,7 +1466,7 @@ void File_Gxf::media()
     #endif //MEDIAINFO_DEMUX
 
     //Needed?
-    if (!Streams[TrackNumber].Searching_Payload)
+    if (!Streams[TrackNumber].Searching_Payload && IsParsingMiddle_MaxOffset==(int64u)-1)
     {
         Skip_XX(Element_Size-Element_Offset,                    "data");
         //Element_DoNotShow();
@@ -1453,6 +1477,10 @@ void File_Gxf::media()
     {
         Streams[TrackNumber].Parsers[Pos]->FrameInfo.DTS=FrameInfo.DTS;
         Open_Buffer_Continue(Streams[TrackNumber].Parsers[Pos], Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset));
+        #if MEDIAINFO_DEMUX
+            if (Config->Demux_EventWasSent && Config->Demux_Unpacketize_Get())
+                Streams[TrackNumber].Demux_EventWasSent=true;
+        #endif //MEDIAINFO_DEMUX
 
         //Multiple parsers
         if (Streams[TrackNumber].Parsers.size()>1)
@@ -1479,7 +1507,7 @@ void File_Gxf::media()
 
     Element_Offset=Element_Size;
 
-    if (MediaInfoLib::Config.ParseSpeed_Get()<1 && Streams[TrackNumber].Parsers.size()==1 && Streams[TrackNumber].Parsers[0]->Status[IsFilled])
+    if (IsParsingMiddle_MaxOffset!=(int64u)-1 && Config->ParseSpeed<1 && Streams[TrackNumber].Parsers.size()==1 && Streams[TrackNumber].Parsers[0]->Status[IsFilled])
     {
         Streams[TrackNumber].Searching_Payload=false;
 
@@ -1487,7 +1515,7 @@ void File_Gxf::media()
             Parsers_Count--;
         if (Parsers_Count==0)
         {
-            Finish();
+            TryToFinish();
         }
     }
 }
@@ -1571,7 +1599,7 @@ void File_Gxf::Detect_EOF()
 {
     if (File_Offset+Buffer_Size>=SizeToAnalyze)
     {
-        Finish();
+        TryToFinish();
     }
 }
 
@@ -1585,7 +1613,7 @@ File__Analyze* File_Gxf::ChooseParser_ChannelGrouping(int8u TrackID)
             return NULL; //Not a channel grouping
 
         Parser=new File_ChannelGrouping;
-        Parser->CanBePcm=true;;
+        Parser->CanBePcm=true;
         Parser->Channel_Pos=1;
         Parser->Common=((File_ChannelGrouping*)Streams[TrackID-1].Parsers[0])->Common;
         Parser->StreamID=TrackID-1;
@@ -1594,7 +1622,7 @@ File__Analyze* File_Gxf::ChooseParser_ChannelGrouping(int8u TrackID)
     else
     {
         Parser=new File_ChannelGrouping;
-        Parser->CanBePcm=true;;
+        Parser->CanBePcm=true;
         Parser->Channel_Pos=0;
         //if (Descriptor->second.Infos.find("SamplingRate")!=Descriptor->second.Infos.end())
         Streams[TrackID].IsChannelGrouping=true;
@@ -1616,6 +1644,21 @@ File__Analyze* File_Gxf::ChooseParser_ChannelGrouping(int8u TrackID)
     return Parser;
 }
 
+//---------------------------------------------------------------------------
+void File_Gxf::TryToFinish()
+{
+    if (!IsSub && File_Size!=(int64u)-1 && Config->ParseSpeed<1 && IsParsingMiddle_MaxOffset==(int64u)-1 && File_Size/2>SizeToAnalyze*4)
+    {
+        IsParsingMiddle_MaxOffset=File_Size/2+SizeToAnalyze*4;
+        GoTo(File_Size/2);
+        Open_Buffer_Unsynch();
+        Parsers_Count=(int8u)-1;
+        return;
+    }
+
+    Finish();
+}
+
 } //NameSpace
 
 #endif //MEDIAINFO_GXF_YES
