@@ -55,6 +55,8 @@ namespace ZenLib
 // Constructor/Destructor
 //***************************************************************************
 
+    int A=0;
+
 //---------------------------------------------------------------------------
 File::File()
 {
@@ -165,7 +167,7 @@ bool File::Open (const tstring &File_Name_, access_t Access)
                 case Access_Read         : dwDesiredAccess=FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING;   break;
                 case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
                 case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;                    break;
-                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
+                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_ALWAYS;   break;
                 default                  : dwDesiredAccess=0;               dwShareMode=0;                                 dwCreationDisposition=0;             break;
             }
 
@@ -190,7 +192,7 @@ bool File::Open (const tstring &File_Name_, access_t Access)
                     lpMsgBuf,
                     1000, NULL );
                     */
-                    Sleep(1000);
+                    //Sleep(1000);
                     #ifdef UNICODE
                         File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                     #else
@@ -281,7 +283,7 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
             if (File_Handle==INVALID_HANDLE_VALUE)
             {
                 //Sometime the file is locked for few milliseconds, we try again later
-                Sleep(3000);
+                //Sleep(3000);
                 #ifdef UNICODE
                     File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                 #else
